.. moduleauthor:: Paul Ross <apaulross@gmail.com>
.. sectionauthor:: Paul Ross <apaulross@gmail.com>

.. TotalDepth API reference.

Plot Package Reference
==========================

Contents:

.. toctree::
	:maxdepth: 2

	Coord
	Stroke
	
	SVGWriter
	
	PlotConstants

	Track
	XGrid
	
	XMLCfg
	XMLMatches
	
	AREACfg
	FILMCfg
	FILMCfgXML
	PRESCfg
	PRESCfgXML
	
	LogHeader
	
	Plot
